@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
  * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org>
+ * * Copyright (C) 2012-2020 Sean Davis <bluesabre@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -67,7 +67,7 @@ parole_dialog_show(GtkWindow *parent,
                         title);
 
     gtk_window_set_title(GTK_WINDOW(dialog), window_title);
-    gtk_window_set_icon_name(GTK_WINDOW(dialog), "parole");
+    gtk_window_set_icon_name(GTK_WINDOW(dialog), "org.xfce.parole");
 
     gtk_message_dialog_format_secondary_markup(GTK_MESSAGE_DIALOG(dialog), "%s", msg);
 
