@@ -43,7 +43,10 @@
 #include <gst/tag/tag.h>
 #include <gst/video/video.h>
 
+#include <gtk/gtk.h>
+#ifdef ENABLE_X11
 #include <gdk/gdkx.h>
+#endif
 
 #include <libxfce4util/libxfce4util.h>
 
@@ -440,10 +443,14 @@ parole_gst_set_video_overlay(ParoleGst *gst) {
 
     g_assert(video_sink != NULL);
 
-    if (GDK_IS_WINDOW (gtk_widget_get_window(GTK_WIDGET (gst)))) {
-        gst_video_overlay_set_window_handle(GST_VIDEO_OVERLAY(video_sink),
-                          GDK_WINDOW_XID(gtk_widget_get_window(GTK_WIDGET(gst))));
+#ifdef ENABLE_X11
+    if (GDK_IS_X11_DISPLAY(gdk_display_get_default())) {
+        if (GDK_IS_WINDOW(gtk_widget_get_window(GTK_WIDGET (gst)))) {
+            gst_video_overlay_set_window_handle(GST_VIDEO_OVERLAY(video_sink),
+                              GDK_WINDOW_XID(gtk_widget_get_window(GTK_WIDGET(gst))));
+        }
     }
+#endif
 
     gst_object_unref(video_sink);
 }
@@ -925,15 +932,17 @@ parole_gst_tag_list_get_cover_external(ParoleGst *gst) {
         else if ( g_strcmp0(lower, "albumartsmall.jpg") == 0 )
             cover = g_strdup(listing);
 
+        g_free(lower);
+
         if (cover) {
             cover_filename = g_build_filename(directory, cover, NULL);
+            g_free(cover);
             break;
         }
     }
     g_free(uri);
     g_free(filename);
     g_free(directory);
-    g_free(lower);
     g_dir_close(file_dir);
 
     if (!cover_filename)
@@ -1457,12 +1466,14 @@ parole_gst_bus_event(GstBus *bus, GstMessage *msg, gpointer data) {
                  details[1] = NULL;
                  ctx = gst_install_plugins_context_new();
 
-#ifdef GDK_WINDOWING_X11
-                if (gtk_widget_get_window(GTK_WIDGET(gst)) != NULL && gtk_widget_get_realized(GTK_WIDGET(gst))) {
-                    gst_install_plugins_context_set_xid(ctx,
-                        gdk_x11_window_get_xid(gtk_widget_get_window(GTK_WIDGET(gst))));
+#ifdef ENABLE_X11
+                if (GDK_IS_X11_DISPLAY(gdk_display_get_default())) {
+                    if (gtk_widget_get_window(GTK_WIDGET(gst)) != NULL && gtk_widget_get_realized(GTK_WIDGET(gst))) {
+                        gst_install_plugins_context_set_xid(ctx,
+                            gdk_x11_window_get_xid(gtk_widget_get_window(GTK_WIDGET(gst))));
+                    }
                 }
-#endif /* GDK_WINDOWING_X11 */
+#endif /* ENABLE_X11 */
 
                 result = gst_install_plugins_async((const gchar * const *) details,
                     ctx, parole_gst_install_plugins_result_func, gst);
@@ -2059,6 +2070,8 @@ parole_gst_constructed(GObject *object) {
     parole_gst_set_subtitle_font(gst);
 
     TRACE("End");
+
+    G_OBJECT_CLASS(parole_gst_parent_class)->constructed(object);
 }
 
 static void
