@@ -166,6 +166,9 @@ ParoleOpenLocation *parole_open_location(GtkWidget *parent) {
     ParoleOpenLocation *self;
     GtkTreeModel *model;
     GtkBuilder *builder;
+    GtkSettings *settings;
+    GtkWidget *cancel, *open;
+    gboolean use_header;
 
     self = g_object_new(PAROLE_TYPE_OPEN_LOCATION, NULL);
 
@@ -189,10 +192,35 @@ ParoleOpenLocation *parole_open_location(GtkWidget *parent) {
                               G_CALLBACK(parole_open_location_clear_history), model);
     gtk_widget_set_tooltip_text(GTK_WIDGET(gtk_builder_get_object(builder, "clear-history")), _("Clear History"));
 
-    g_signal_connect_swapped(gtk_builder_get_object(builder, "cancel"), "clicked",
-                             G_CALLBACK(parole_open_location_close), self);
-    g_signal_connect_swapped(gtk_builder_get_object(builder, "open"), "clicked",
-                             G_CALLBACK(parole_open_location_open), self);
+    settings = gtk_settings_get_default();
+    g_object_get(settings, "gtk-dialogs-use-header", &use_header, NULL);
+
+    cancel = GTK_WIDGET(gtk_builder_get_object(builder, "cancel"));
+    open = GTK_WIDGET(gtk_builder_get_object(builder, "open"));
+
+    if ( !use_header ) {
+        GtkWidget *titlebar, *action_area;
+
+        gtk_window_set_titlebar(GTK_WINDOW(self->dialog), NULL);
+
+        titlebar = GTK_WIDGET(gtk_builder_get_object(builder, "titlebar"));
+        action_area = GTK_WIDGET(gtk_builder_get_object(builder, "dialog-action_area1"));
+
+        g_object_ref(cancel);
+        g_object_ref(open);
+        gtk_container_remove(GTK_CONTAINER(titlebar), cancel);
+        gtk_container_remove(GTK_CONTAINER(titlebar), open);
+        gtk_box_pack_start (GTK_BOX(action_area), cancel, FALSE, TRUE, 0);
+        gtk_box_pack_start (GTK_BOX(action_area), open, FALSE, TRUE, 0);
+        g_object_unref(cancel);
+        g_object_unref(open);
+    }
+
+    g_signal_connect_swapped(cancel, "clicked",
+                      G_CALLBACK(parole_open_location_close), self);
+
+    g_signal_connect_swapped(open, "clicked",
+                      G_CALLBACK(parole_open_location_open), self);
 
     g_signal_connect(self->dialog, "delete-event",
                       G_CALLBACK(gtk_widget_destroy), NULL);
