@@ -29,6 +29,13 @@
 #include <string.h>
 
 #include <glib.h>
+#include <gtk/gtk.h>
+#ifdef ENABLE_X11
+#include <gdk/gdkx.h>
+#define WINDOWING_IS_X11() GDK_IS_X11_DISPLAY (gdk_display_get_default ())
+#else
+#define WINDOWING_IS_X11() FALSE
+#endif
 
 #ifdef XFCE_DISABLE_DEPRECATED
 #undef XFCE_DISABLE_DEPRECATED
@@ -652,6 +659,10 @@ void parole_plugins_manager_load(ParolePluginsManager *manager) {
         gchar *library_name;
         gchar *desktop_file;
 
+        /* FIXME: https://gitlab.xfce.org/apps/parole/-/issues/126 */
+        if (g_strcmp0(name, "system-tray.desktop") == 0 && !WINDOWING_IS_X11())
+            continue;
+
         desktop_file = g_build_filename(PAROLE_PLUGINS_DATA_DIR, name, NULL);
         library_name = parole_plugins_manager_get_module_name(desktop_file);
 
